#ifndef SETTINGGROUP_H
#define SETTINGGROUP_H

#include <QWidget>
#include <QFrame>
#include <QVBoxLayout>
#include <QDBusInterface>
#include <QDBusReply>
#include <QDebug>

#define tabletHeight 64
#define pcHeight 60

#include "libukcc_global.h"
#include "ukccframe.h"

/**
 * @brief 创建一个 Spacing 为 1 的垂直布局 Frame
 *
 */
class LIBUKCC_EXPORT SettingGroup : public UkccFrame
{
    Q_OBJECT
public:
    /**
     * @brief 创建一个 Spacing 为 1 的垂直布局 Frame
     *
     * @param Shape: 设置frameShap
     * @param style: 设置圆角（None:无圆角,Top:上圆角,Bottom:下圆角,Around:四圆角）
     * @param parent
     */
    explicit SettingGroup(QWidget *parent = nullptr, Shape shape = QFrame::NoFrame, UkccFrame::BorderRadiusStyle style = UkccFrame::None);

    /**
     * @brief
     *
     */
    ~SettingGroup();

    /**
     * @brief 为 mainLayout 添加控件并更新圆角
     *
     * @param index: 序号
     * @param item:  需要添加的控件
     */
    void insertWidget(int index, QFrame *item);

    /**
     * @brief 为 mainLayout 移除控件并更新圆角
     *
     * @param w:  需要移除的控件
     */
    void removeWidget(QWidget *w);

    /**
     * @brief 更新圆角
     *
     */
    void updateShape();

    /**
     * @brief 监听平板pc模式变化设置控件高度
     *
     */
    void monitorTabletMode();

    /**
     * @brief
     *
     * @return QVBoxLayout
     */
    QVBoxLayout *layout();

private:
    QDBusInterface *m_statusSessionDbus = nullptr; /**< TODO: describe */
    QVBoxLayout *mainLayout; /**< TODO: 控件布局 */

private Q_SLOTS:
    /**
     * @brief 平板与 pc 切换槽函数
     * @param istablet
     */
    void tabletModeChanged(bool istablet);

Q_SIGNALS:

};

#endif // SETTINGGROUP_H
